##  Aligned Catalog Items: Applications and IT Components
In the catalog settings for applications, you can enable the automated creation of relations to IT components (as well as relations to providers and tech categories for IT components). This enables you to enrich and automatically complete your portfolio. This alignment ensures there are no duplications if you’re using both applications and IT components from the catalog.
If you've enabled the linking of applications to IT components in the catalog settings, when a SaaS application is linked to a catalog item, the associated SaaS hosting IT component fact sheet is automatically created and linked to the catalog. In this context, SaaS hosting means that an application is hosted as a SaaS product.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
